==> mongodb-5.0.31.gh.tar.gz: mongo-r5.0.31/src/mongo/db/s/transaction_coordinator_worker_curop_info.h <==
/**
 *    Copyright (C) 2019-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#pragma once

#include "mongo/db/s/transaction_coordinator_worker_curop_repository.h"

#include "mongo/db/curop.h"

namespace mongo {
class TransactionCoordinatorWorkerCurOpInfo {
    using CoordinatorAction = TransactionCoordinatorWorkerCurOpRepository::CoordinatorAction;
    TransactionCoordinatorWorkerCurOpInfo() = delete;

public:
    TransactionCoordinatorWorkerCurOpInfo(LogicalSessionId lsid,
                                          TxnNumber txnNumber,
                                          Date_t startTime,
                                          CoordinatorAction action);

    void reportState(BSONObjBuilder* parent) const;

private:
    static const std::string toString(CoordinatorAction action);

    LogicalSessionId _lsid;
    TxnNumber _txnNumber;
    Date_t _startTime;
    CoordinatorAction _action;
};
}  // namespace mongo

==> mongodb-6.0.27.gh.tar.gz: mongo-r6.0.27/src/mongo/db/s/transaction_coordinator_worker_curop_info.h <==
/**
 *    Copyright (C) 2019-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#pragma once

#include "mongo/db/s/transaction_coordinator_worker_curop_repository.h"

#include "mongo/db/curop.h"

namespace mongo {
class TransactionCoordinatorWorkerCurOpInfo {
    using CoordinatorAction = TransactionCoordinatorWorkerCurOpRepository::CoordinatorAction;
    TransactionCoordinatorWorkerCurOpInfo() = delete;

public:
    TransactionCoordinatorWorkerCurOpInfo(LogicalSessionId lsid,
                                          TxnNumberAndRetryCounter txnNumberAndRetryCounter,
                                          Date_t startTime,
                                          CoordinatorAction action);

    void reportState(BSONObjBuilder* parent) const;

private:
    static const std::string toString(CoordinatorAction action);

    LogicalSessionId _lsid;
    TxnNumberAndRetryCounter _txnNumberAndRetryCounter;
    Date_t _startTime;
    CoordinatorAction _action;
};
}  // namespace mongo
